@@ -37,7 +37,6 @@
 #define SN_API_NOT_YET_FROZEN
 #include <libsn/sn.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 
 #include <totem-pl-parser.h>
 
@@ -1481,7 +1480,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 
 	gtk_widget_set_size_request (emb->window, width, height);
 
-#if GNOME_ENABLE_DEBUG
+#ifdef GNOME_ENABLE_DEBUG
 	child = glade_xml_get_widget (emb->xml, "controls");
 	g_signal_connect_after (child, "size-allocate", G_CALLBACK (controls_size_allocate_cb), NULL);
 #endif
@@ -1646,10 +1645,19 @@ totem_embedded_clear_playlist (TotemEmbedded *embedded)
 }
 
 static void
-entry_added (TotemPlParser *parser,
+entry_metadata_foreach (const char *key,
+			const char *value,
+			gpointer data)
+{
+	if (g_ascii_strcasecmp (key, "url") == 0)
+		return;
+	g_print ("\t%s = '%s'\n", key, value);
+}
+
+static void
+entry_parsed (TotemPlParser *parser,
 	     const char *uri,
-	     const char *title,
-	     const char *genre,
+	     GHashTable *metadata,
 	     gpointer data)
 {
 	TotemEmbedded *emb = (TotemEmbedded *) data;
@@ -1660,8 +1668,8 @@ entry_added (TotemPlParser *parser,
 		return;
 	}
 
-	g_print ("added URI '%s' with title '%s' genre '%s'\n", uri,
-			title ? title : "empty", genre);
+	g_print ("added URI '%s'\n", uri);
+	g_hash_table_foreach (metadata, (GHFunc) entry_metadata_foreach, NULL);
 
 	//FIXMEchpe
 	//FIXME need new struct to hold that
@@ -1682,7 +1690,7 @@ totem_embedded_push_parser (gpointer data)
 	g_object_set (parser, "force", TRUE,
 		      "disable-unsafe", TRUE,
 		      NULL);
-	g_signal_connect (parser, "entry", G_CALLBACK (entry_added), emb);
+	g_signal_connect (parser, "entry-parsed", G_CALLBACK (entry_parsed), emb);
 	res = totem_pl_parser_parse_with_base (parser, emb->current_uri,
 					       emb->base_uri, FALSE);
 	g_object_unref (parser);
@@ -1734,7 +1742,7 @@ totem_volume_create (void)
 	GtkWidget *widget;
 
 	widget = bacon_volume_button_new (GTK_ICON_SIZE_MENU,
-					  0, 100, -1);
+					  0, 100, 1);
 	gtk_button_set_focus_on_click (GTK_BUTTON (widget), FALSE);
 	gtk_widget_show (widget);
 
@@ -1747,7 +1755,7 @@ totem_statusbar_create (void)
 	GtkWidget *widget;
 
 	widget = totem_statusbar_new ();
-	totem_statusbar_set_has_resize_grip (TOTEM_STATUSBAR (widget), FALSE);
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (widget), FALSE);
 	gtk_widget_show (widget);
 
 	return widget;
