@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemGMPPlugin.cpp 4294 2007-05-10 14:23:49Z hadess $
+ * $Id: totemGMPPlugin.cpp 4293 2007-05-10 14:23:07Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -59,21 +59,14 @@ static const char kClassDescription[] = "totemGMPPlugin";
 static const char kPluginDescription[] = "Windows Media Player Plug-in 10 (compatible; Totem)";
 
 static const totemPluginMimeEntry kMimeTypes[] = {
-	{ "application/x-mplayer2", "avi, wma, wmv", "video/x-msvideo", FALSE },
-	{ "video/x-ms-asf-plugin", "asf, wmv", "video/x-ms-asf", FALSE },
-	{ "video/x-msvideo", "asf, wmv", NULL, FALSE },
-	{ "video/x-ms-asf", "asf", NULL, FALSE },
-	{ "video/x-ms-wmv", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-wmv", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-ms-wvx", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-ms-wm", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-ms-asx", "asx", NULL, TRUE },
-	{ "audio/x-ms-asx", "asx", NULL, TRUE },
-	{ "video/x-ms-wma", "wma", NULL, TRUE },
-	{ "audio/x-ms-wax", "wax", NULL, TRUE },
-	{ "video/mpeg", "mpg", NULL, TRUE },
-	{ "audio/mpeg", "mp3", NULL, TRUE },
-	{ "audio/x-mpegurl", "m3u", NULL, TRUE }
+	{ "application/x-mplayer2", "avi, wma, wmv", "video/x-msvideo" },
+	{ "video/x-ms-asf-plugin", "asf, wmv", "video/x-ms-asf" },
+	{ "video/x-msvideo", "asf, wmv", NULL },
+	{ "video/x-ms-asf", "asf", NULL },
+	{ "video/x-ms-wmv", "wmv", "video/x-ms-wmv" },
+	{ "video/x-wmv", "wmv", "video/x-ms-wmv" },
+	{ "video/x-ms-wvx", "wmv", "video/x-ms-wmv" },
+	{ "video/x-ms-wm", "wmv", "video/x-ms-wmv" },
 };
 
 void*
