@@ -20,7 +20,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -172,21 +172,19 @@ void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
 
-void bacon_video_widget_set_media_device         (BaconVideoWidget *bvw,
-						  const char *path);
 gboolean bacon_video_widget_can_play             (BaconVideoWidget *bvw,
 						  MediaType type);
+
+#define MEDIA_TYPE_DVB MEDIA_TYPE_NUM_TYPES
+
 gchar **bacon_video_widget_get_mrls		 (BaconVideoWidget *bvw,
-						  MediaType type);
+						  MediaType type,
+						  const char *device);
 void bacon_video_widget_set_subtitle_font	 (BaconVideoWidget *bvw,
 						  const char *font);
 void bacon_video_widget_set_subtitle_encoding	 (BaconVideoWidget *bvw,
 						  const char *encoding);
 
-/* Video devices */
-void bacon_video_widget_set_video_device	 (BaconVideoWidget *bvw,
-						  const char *path);
-
 /* Metadata */
 typedef enum {
 	BVW_INFO_TITLE,
