@@ -1,5 +1,6 @@
 /* Totem Disc Content Detection
- * (c) 2004 Ronald Bultje <rbultje@ronald.bitfreak.net>
+ * Copyright (C) 2004 Ronald Bultje <rbultje@ronald.bitfreak.net>
+ * Copyright (C) 2004-2007 Bastien Nocera <hadess@hadess.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,7 +22,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -56,8 +57,6 @@ typedef struct _CdCache {
 
 #ifdef HAVE_HAL
   LibHalContext *ctx;
-#endif
-#ifdef HAVE_HAL_0_5
   /* If the disc is a media, have the UDI available here */
   char *disc_udi;
 #endif
@@ -76,73 +75,34 @@ typedef struct _CdCache {
   guint mounted : 1;
 } CdCache;
 
-/* 
- * Resolve relative paths
- */
-
 static char *
-totem_disc_resolve_link (const char *dev, const char *buf)
+totem_resolve_symlink (const char *device, GError **error)
 {
-  char *parent, *new, *result;
+  char *dir, *link;
+  char *f;
+  char *f1;
 
-  /* is it an absolute path? */
-  if (g_path_is_absolute (buf) != FALSE) {
-    result = realpath (buf, NULL);
-    if (result == NULL)
-      result = g_strdup (buf);
-  } else {
-    parent = g_path_get_dirname (dev);
-    new = g_build_filename (parent, buf, NULL);
-    result = realpath (new, NULL);
-    if (result == NULL)
-      result = g_strdup (new);
-    g_free (new);
-    g_free (parent);
-  }
-
-  return result;
-}
-
-/*
- * So, devices can be symlinks and that screws up.
- */
-
-static char *
-get_device (const char *device,
-	    GError     **error)
-{
-  char *buf;
-  char *dev = g_strdup (device);
-  struct stat st;
-
-  while (1) {
-    char *new;
-
-    if (lstat (dev, &st) != 0) {
-      g_set_error (error, 0, 0,
-          _("Failed to find real device node for %s: %s"),
-          dev, g_strerror (errno));
-      g_free (dev);
+  f = g_strdup (device);
+  while (g_file_test (f, G_FILE_TEST_IS_SYMLINK)) {
+    link = g_file_read_link (f, error);
+    if(link == NULL) {
+      g_free (f);
       return NULL;
     }
 
-    if (!S_ISLNK (st.st_mode))
-      break;
-
-    if (!(buf = g_file_read_link (dev, NULL))) {
-      g_set_error (error, 0, 0,
-          _("Failed to read symbolic link %s: %s"),
-          dev, g_strerror (errno));
-      g_free (dev);
-      return NULL;
-    }
-    new = totem_disc_resolve_link (dev, buf);
-    g_free (dev);
-    g_free (buf);
-    dev = new;
+    dir = g_path_get_dirname (f);
+    f1 = g_build_filename (dir, link, NULL);
+    g_free (dir);
+    g_free (f);
+    f = f1;
   }
 
-  return dev;
+  if (f != NULL) {
+    f1 = gnome_vfs_make_path_name_canonical (f);
+    g_free (f);
+    f = f1;
+  }
+  return f;
 }
 
 static gboolean
@@ -162,7 +122,7 @@ cd_cache_get_dev_from_volumes (GnomeVFSVolumeMonitor *mon, const char *device,
     volume = list->data;
     if (!(pdev = gnome_vfs_volume_get_device_path (volume)))
       continue;
-    pdev2 = get_device (pdev, NULL);
+    pdev2 = totem_resolve_symlink (pdev, NULL);
     if (!pdev2) {
       g_free (pdev);
       continue;
@@ -213,7 +173,7 @@ cd_cache_get_dev_from_drives (GnomeVFSVolumeMonitor *mon, const char *device,
     drive = list->data;
     if (!(pdev = gnome_vfs_drive_get_device_path (drive)))
       continue;
-    pdev2 = get_device (pdev, NULL);
+    pdev2 = totem_resolve_symlink (pdev, NULL);
     if (!pdev2) {
       g_free (pdev);
       continue;
@@ -245,17 +205,7 @@ cd_cache_get_dev_from_drives (GnomeVFSVolumeMonitor *mon, const char *device,
   return found;
 }
 
-#ifdef HAVE_HAL_0_2
-static LibHalContext *
-cd_cache_new_hal_ctx (void)
-{
-  LibHalContext *ctx;
-
-  ctx = hal_initialize (NULL, FALSE);
-
-  return ctx;
-}
-#elif HAVE_HAL_0_5
+#ifdef HAVE_HAL
 static LibHalContext *
 cd_cache_new_hal_ctx (void)
 {
@@ -268,12 +218,8 @@ cd_cache_new_hal_ctx (void)
     return NULL;
 
   dbus_error_init (&error);
-#if (DBUS_VERSION_MAJOR == 0) && (DBUS_VERSION_MINOR < 60)
-  conn = dbus_bus_get (DBUS_BUS_SYSTEM, &error);
-  g_warning ("might crash, see http://bugzilla.gnome.org/show_bug.cgi?id=345203");
-#else
   conn = dbus_bus_get_private (DBUS_BUS_SYSTEM, &error);
-#endif
+
   if (conn != NULL && !dbus_error_is_set (&error)) {
     if (!libhal_ctx_set_dbus_connection (ctx, conn)) {
       libhal_ctx_free (ctx);
@@ -289,8 +235,10 @@ cd_cache_new_hal_ctx (void)
   }
 
   libhal_ctx_free (ctx);
-  if (conn != NULL)
+  if (conn != NULL) {
+    dbus_connection_close (conn);
     dbus_connection_unref (conn);
+  }
 
   return NULL;
 }
@@ -325,7 +273,7 @@ cd_cache_new (const char *dev,
   }
 
   /* retrieve mountpoint from gnome-vfs volumes and drives */
-  device = get_device (local, error);
+  device = totem_resolve_symlink (local, error);
   g_free (local);
   if (!device)
     return NULL;
@@ -370,11 +318,11 @@ cd_cache_new (const char *dev,
 static gboolean
 cd_cache_has_medium (CdCache *cache)
 {
-  return FALSE;
+  return TRUE;
 }
 #endif
 
-#ifdef HAVE_HAL_0_5
+#ifdef HAVE_HAL
 static gboolean
 cd_cache_has_medium (CdCache *cache)
 {
@@ -407,6 +355,12 @@ cd_cache_has_medium (CdCache *cache)
   if (retval == FALSE) {
     dbus_bool_t volume;
 
+    if (libhal_device_property_exists (cache->ctx,
+	  udi, "volume.is_disc", NULL) == FALSE) {
+      g_free (udi);
+      return FALSE;
+    }
+
     volume = libhal_device_get_property_bool (cache->ctx,
 	udi, "volume.is_disc", &error);
     if (dbus_error_is_set (&error)) {
@@ -427,32 +381,6 @@ cd_cache_has_medium (CdCache *cache)
 
   return retval;
 }
-#elif HAVE_HAL_0_2
-static gboolean
-cd_cache_has_medium (CdCache *cache)
-{
-  char **devices;
-  int num_devices;
-  char *udi;
-  gboolean retval = FALSE;
-
-  if (cache->drive == NULL)
-    return FALSE;
- 
-  udi = gnome_vfs_drive_get_hal_udi (cache->drive);
-  if (udi == NULL)
-    return FALSE;
-
-  devices = hal_manager_find_device_string_match (cache->ctx,
-      "info.parent", udi, &num_devices);
-  if (devices != NULL && num_devices >= 1)
-    retval = TRUE;
-
-  hal_free_string_array (devices);
-  g_free (udi);
-
-  return retval;
-}
 #endif
 
 static gboolean
@@ -484,7 +412,7 @@ cb_mount_done (gboolean success, char * error,
                char * detail, CdCacheCallbackData * data)
 {
   data->called = TRUE;
-  data->cache->mounted = success;
+  data->cache->mounted = success != FALSE;
 }
 
 static gboolean
@@ -509,7 +437,7 @@ cd_cache_open_mountpoint (CdCache *cache,
     data.cache = cache;
     gnome_vfs_drive_mount (cache->drive,
 	(GnomeVFSVolumeOpCallback) cb_mount_done, &data);
-    while (!data.called) g_main_iteration (TRUE);
+    while (!data.called) g_main_context_iteration (NULL, TRUE);
 
     if (!cache->mounted) {
       g_set_error (error, 0, 0,
@@ -561,28 +489,21 @@ cd_cache_free (CdCache *cache)
 
     gnome_vfs_drive_unmount (cache->drive,
 	(GnomeVFSVolumeOpCallback) cb_umount_done, &called);
-    while (!called) g_main_iteration (TRUE);
+    while (!called) g_main_context_iteration (NULL, TRUE);
   }
 
 #ifdef HAVE_HAL
   if (cache->ctx != NULL) {
-#ifdef HAVE_HAL_0_5
     DBusConnection *conn;
 
     conn = libhal_ctx_get_dbus_connection (cache->ctx);
     libhal_ctx_shutdown (cache->ctx, NULL);
     libhal_ctx_free(cache->ctx);
-#if (DBUS_VERSION_MAJOR == 0) && (DBUS_VERSION_MINOR < 60)
-    dbus_connection_unref (conn);
-#else
+    /* Close the connection before doing the last unref */
     dbus_connection_close (conn);
     dbus_connection_unref (conn);
-#endif
 
     g_free (cache->disc_udi);
-#elif HAVE_HAL_0_2
-    hal_shutdown (cache->ctx);
-#endif
   }
 #endif /* HAVE_HAL */
 
@@ -606,7 +527,7 @@ cd_cache_disc_is_cdda (CdCache *cache,
   if (!cd_cache_open_device (cache, error))
     return MEDIA_TYPE_ERROR;
 
-#ifdef HAVE_HAL_0_5
+#ifdef HAVE_HAL
   {
     DBusError error;
     dbus_bool_t is_cdda;
@@ -709,7 +630,7 @@ cd_cache_disc_is_vcd (CdCache *cache,
     return MEDIA_TYPE_ERROR;
   if (!cache->mountpoint)
     return MEDIA_TYPE_ERROR;
-#ifdef HAVE_HAL_0_5
+#ifdef HAVE_HAL
   if (cache->is_media != FALSE) {
     DBusError error;
     dbus_bool_t is_vcd;
@@ -758,7 +679,7 @@ cd_cache_disc_is_dvd (CdCache *cache,
     return MEDIA_TYPE_ERROR;
   if (!cache->mountpoint)
     return MEDIA_TYPE_ERROR;
-#ifdef HAVE_HAL_0_5
+#ifdef HAVE_HAL
   if (cache->is_media != FALSE) {
     DBusError error;
     dbus_bool_t is_dvd;
@@ -893,6 +814,21 @@ totem_cd_detect_type (const char  *device,
   return totem_cd_detect_type_with_url (device, NULL, error);
 }
 
+gboolean
+totem_cd_has_medium (const char  *device)
+{
+  CdCache *cache;
+  gboolean retval = TRUE;
+
+  if (!(cache = cd_cache_new (device, NULL)))
+    return TRUE;
+
+  retval = cd_cache_has_medium (cache);
+  cd_cache_free (cache);
+
+  return retval;
+}
+
 const char *
 totem_cd_get_human_readable_name (MediaType type)
 {
