@@ -149,7 +149,7 @@ static void totem_playlist_init       (TotemPlaylist      *playlist);
 
 static void init_treeview (GtkWidget *treeview, TotemPlaylist *playlist);
 
-#define totem_playlist_unset_playing(x) totem_playlist_set_playing(x, FALSE)
+#define totem_playlist_unset_playing(x) totem_playlist_set_playing(x, TOTEM_PLAYLIST_STATUS_NONE)
 
 G_DEFINE_TYPE(TotemPlaylist, totem_playlist, GTK_TYPE_VBOX)
 
@@ -262,24 +262,6 @@ totem_playlist_mrl_to_title (const gchar *mrl)
 	return filename_for_display;
 }
 
-static gboolean
-totem_playlist_is_media (const char *mrl)
-{
-	if (mrl == NULL)
-		return FALSE;
-
-	if (g_str_has_prefix (mrl, "cdda:") != FALSE)
-		return TRUE;
-	if (g_str_has_prefix (mrl, "dvd:") != FALSE)
-		return TRUE;
-	if (g_str_has_prefix (mrl, "vcd:") != FALSE)
-		return TRUE;
-	if (g_str_has_prefix (mrl, "cd:") != FALSE)
-		return TRUE;
-
-	return FALSE;
-}
-
 static void
 totem_playlist_update_save_button (TotemPlaylist *playlist)
 {
@@ -291,43 +273,6 @@ totem_playlist_update_save_button (TotemPlaylist *playlist)
 	gtk_widget_set_sensitive (button, state);
 }
 
-static char*
-totem_playlist_create_full_path (const char *path)
-{
-	char *retval, *curdir, *curdir_withslash, *escaped;
-
-	g_return_val_if_fail (path != NULL, NULL);
-
-	if (strstr (path, "://") != NULL)
-		return g_strdup (path);
-	if (totem_playlist_is_media (path) != FALSE)
-		return g_strdup (path);
-
-	if (path[0] == '/')
-	{
-		escaped = gnome_vfs_escape_path_string (path);
-
-		retval = g_strdup_printf ("file://%s", escaped);
-		g_free (escaped);
-		return retval;
-	}
-
-	curdir = g_get_current_dir ();
-	escaped = gnome_vfs_escape_path_string (curdir);
-	curdir_withslash = g_strdup_printf ("file://%s%s",
-			escaped, G_DIR_SEPARATOR_S);
-	g_free (escaped);
-	g_free (curdir);
-
-	escaped = gnome_vfs_escape_path_string (path);
-	retval = gnome_vfs_uri_make_full_from_relative
-		(curdir_withslash, escaped);
-	g_free (curdir_withslash);
-	g_free (escaped);
-
-	return retval;
-}
-
 static void
 totem_playlist_save_get_iter_func (GtkTreeModel *model,
 		GtkTreeIter *iter, char **uri, char **title,
@@ -436,8 +381,7 @@ drop_cb (GtkWidget     *widget,
 		filename = totem_create_full_path (p->data);
 		title = NULL;
 
-		if (info == 1)
-		{
+		if (info == 1) {
 			g_free (p->data);
 			p = p->next;
 			if (p != NULL) {
@@ -448,7 +392,7 @@ drop_cb (GtkWidget     *widget,
 			}
 		}
 
-		totem_playlist_add_mrl (playlist, p->data, title);
+		totem_playlist_add_mrl (playlist, filename ? filename : p->data, title);
 
 		g_free (filename);
 		g_free (p->data);
@@ -576,7 +520,7 @@ totem_playlist_set_reorderable (TotemPlaylist *playlist, gboolean set)
 		GtkTreeIter iter;
 		char *index;
 		GtkTreePath *path;
-		gboolean playing;
+		TotemPlaylistStatus playing;
 
 		index = g_strdup_printf ("%d", i);
 		if (gtk_tree_model_get_iter_from_string
@@ -589,9 +533,8 @@ totem_playlist_set_reorderable (TotemPlaylist *playlist, gboolean set)
 		g_free (index);
 
 		gtk_tree_model_get (playlist->_priv->model, &iter, PLAYING_COL, &playing, -1);
-		if (!playing) {
+		if (playing == TOTEM_PLAYLIST_STATUS_NONE)
 			continue;
-		}
 
 		/* Only emit the changed signal if we changed the ->current */
 		path = gtk_tree_path_new_from_indices (i, -1);
@@ -1159,14 +1102,25 @@ totem_playlist_key_press (GtkWidget *win, GdkEventKey *event, TotemPlaylist *pla
 
 static void
 set_playing_icon (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
-		GtkTreeModel *model, GtkTreeIter *iter, TotemPlaylist *playlist)
+		  GtkTreeModel *model, GtkTreeIter *iter, TotemPlaylist *playlist)
 {
-	gboolean playing;
+	TotemPlaylistStatus playing;
+	const char *stock_id;
 
 	gtk_tree_model_get (model, iter, PLAYING_COL, &playing, -1);
 
-	g_object_set (renderer, "icon-name",
-		      playing ? "audio-volume-medium" : NULL, NULL);
+	switch (playing) {
+		case TOTEM_PLAYLIST_STATUS_PLAYING:
+			stock_id = GTK_STOCK_MEDIA_PLAY;
+			break;
+		case TOTEM_PLAYLIST_STATUS_PAUSED:
+			stock_id = GTK_STOCK_MEDIA_PAUSE;
+			break;
+		default:
+			stock_id = NULL;
+	}
+
+	g_object_set (renderer, "stock-id", stock_id, NULL);
 }
 
 static void
@@ -1252,7 +1206,7 @@ init_treeview (GtkWidget *treeview, TotemPlaylist *playlist)
 
 	/* the model */
 	model = GTK_TREE_MODEL (gtk_list_store_new (NUM_COLS,
-				G_TYPE_BOOLEAN,
+				G_TYPE_INT,
 				G_TYPE_STRING,
 				G_TYPE_STRING,
 				G_TYPE_BOOLEAN,
@@ -1451,9 +1405,13 @@ init_config (TotemPlaylist *playlist)
 
 static void
 totem_playlist_entry_parsed (TotemPlParser *parser,
-		const char *uri, const char *title,
-		const char *genre, TotemPlaylist *playlist)
+			     const char *uri,
+			     GHashTable *metadata,
+			     TotemPlaylist *playlist)
 {
+	const char *title;
+
+	title = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_TITLE);
 	totem_playlist_add_one_mrl (playlist, uri, title);
 }
 
@@ -1490,9 +1448,10 @@ totem_playlist_init (TotemPlaylist *playlist)
 	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cdda:");
 	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "vcd:");
 	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cd:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "dvb:");
 
 	g_signal_connect (G_OBJECT (playlist->_priv->parser),
-			"entry",
+			"entry-parsed",
 			G_CALLBACK (totem_playlist_entry_parsed),
 			playlist);
 
@@ -1603,16 +1562,16 @@ totem_playlist_add_one_mrl (TotemPlaylist *playlist, const char *mrl,
 		filename_for_display = g_strdup (display_name);
 	}
 
-	uri = totem_playlist_create_full_path (mrl);
+	uri = totem_create_full_path (mrl);
 
 	D("totem_playlist_add_one_mrl (): %s %s %s\n",
-				filename_for_display, uri, display_name);
+				filename_for_display, uri ? uri : "(null)", display_name);
 
 	store = GTK_LIST_STORE (playlist->_priv->model);
 	gtk_list_store_insert_with_values (store, &iter, G_MAXINT32,
-			PLAYING_COL, FALSE,
+			PLAYING_COL, TOTEM_PLAYLIST_STATUS_NONE,
 			FILENAME_COL, filename_for_display,
-			URI_COL, uri,
+			URI_COL, uri ? uri : mrl,
 			TITLE_CUSTOM_COL, display_name ? TRUE : FALSE,
 			-1);
 
@@ -1811,8 +1770,8 @@ totem_playlist_clear_with_gnome_vfs_volume (TotemPlaylist *playlist,
 			volume);
 }
 
-char
-*totem_playlist_get_current_mrl (TotemPlaylist *playlist)
+char *
+totem_playlist_get_current_mrl (TotemPlaylist *playlist)
 {
 	GtkTreeIter iter;
 	char *path;
@@ -1834,8 +1793,8 @@ char
 	return path;
 }
 
-char
-*totem_playlist_get_current_title (TotemPlaylist *playlist, gboolean *custom)
+char *
+totem_playlist_get_current_title (TotemPlaylist *playlist, gboolean *custom)
 {
 	GtkTreeIter iter;
 	char *path;
@@ -1983,7 +1942,7 @@ totem_playlist_set_title (TotemPlaylist *playlist, const char *title, gboolean f
 }
 
 gboolean
-totem_playlist_set_playing (TotemPlaylist *playlist, gboolean state)
+totem_playlist_set_playing (TotemPlaylist *playlist, TotemPlaylistStatus state)
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
