@@ -22,7 +22,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -38,6 +38,7 @@
 #include "totem.h"
 #include "totem-private.h"
 #include "totem-preferences.h"
+#include "totem-interface.h"
 #include "video-utils.h"
 #include "totem-subtitle-encoding.h"
 
@@ -71,23 +72,6 @@ totem_action_info (char *reason, Totem *totem)
 	gtk_widget_show (error_dialog);
 }
 
-static char *
-get_stock_label (const char *stock_id)
-{
-	GtkStockItem stock_item;
-	char *label, **split;
-
-	if (gtk_stock_lookup (stock_id, &stock_item) == FALSE) {
-		g_warning ("Couldn't get stock item for '%s'", stock_id);
-		return NULL;
-	}
-	split = g_strsplit (dgettext(stock_item.translation_domain, stock_item.label),
-			      "_", 2);
-	label = g_strjoinv ("", split);
-	g_strfreev (split);
-	return label;
-}
-
 static gboolean
 ask_show_visuals (Totem *totem)
 {
@@ -444,7 +428,7 @@ totem_setup_preferences (Totem *totem)
 	GtkAction *action;
 	gboolean show_visuals, auto_resize, is_local, deinterlace;
 	int connection_speed, i;
-	char *label, *visual, *font, *encoding;
+	char *visual, *font, *encoding;
 	GList *list, *l;
 	BaconVideoWidgetAudioOutType audio_out;
 	GConfValue *value;
@@ -472,14 +456,12 @@ totem_setup_preferences (Totem *totem)
 	/* Work-around glade dialogue not parenting properly for
 	 * On top windows */
 	item = glade_xml_get_widget (totem->xml, "tpw_notebook");
-	label = get_stock_label (GTK_STOCK_PREFERENCES);
-	totem->prefs = gtk_dialog_new_with_buttons (label,
+	totem->prefs = gtk_dialog_new_with_buttons (_("Preferences"),
 			GTK_WINDOW (totem->win),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CLOSE,
 			GTK_RESPONSE_ACCEPT,
 			NULL);
-	g_free (label);
 	gtk_dialog_set_has_separator (GTK_DIALOG (totem->prefs), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (totem->prefs), 5);
 	gtk_box_set_spacing (GTK_BOX(GTK_DIALOG(totem->prefs)->vbox), 2);
@@ -488,6 +470,15 @@ totem_setup_preferences (Totem *totem)
 	item = glade_xml_get_widget (totem->xml, "totem_preferences_window");
 	gtk_widget_destroy (item);
 
+	/* Boldify some labels */
+	totem_interface_boldify_label (totem->xml, "tpw_network_label");
+	totem_interface_boldify_label (totem->xml, "tpw_tvout_label");
+	totem_interface_boldify_label (totem->xml, "tpw_text_subtitles_label");
+	totem_interface_boldify_label (totem->xml, "tpw_display_label");
+	totem_interface_boldify_label (totem->xml, "tpw_visuals_label");
+	totem_interface_boldify_label (totem->xml, "tpw_color_balance_label");
+	totem_interface_boldify_label (totem->xml, "tpw_audio_output_label");
+
 	g_signal_connect (G_OBJECT (totem->prefs), "response",
 			G_CALLBACK (gtk_widget_hide), NULL);
 	g_signal_connect (G_OBJECT (totem->prefs), "delete-event",
@@ -619,13 +610,6 @@ totem_setup_preferences (Totem *totem)
 			(GConfClientNotifyFunc) deinterlace_changed_cb,
 			totem, NULL, NULL);
 
-	/* Always On Top */
-	action = gtk_action_group_get_action (totem->main_action_group,
-			"always-on-top");
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-			gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/window_on_top", NULL));
-
 	/* Save to disk Lockdown */
 	action = gtk_action_group_get_action (totem->main_action_group,
 			"take-screenshot");
