@@ -20,7 +20,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -33,12 +33,9 @@
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-#include "totem-remote.h"
-#include "totem-scrsaver.h"
 #include "totem-playlist.h"
 #include "bacon-message-connection.h"
 #include "bacon-video-widget.h"
-#include "totem-skipto.h"
 
 #define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
 #define totem_signal_unblock_by_data(obj, data) (g_signal_handlers_unblock_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
@@ -70,7 +67,9 @@ typedef enum {
 	STATE_STOPPED
 } TotemStates;
 
-struct Totem {
+struct TotemObject {
+	GObject parent;
+
 	/* Control window */
 	GladeXML *xml;
 	GtkWidget *win;
@@ -92,28 +91,24 @@ struct Totem {
 	GtkActionGroup *subtitles_action_group;
 	guint subtitles_ui_id;
 
+	/* Plugins */
+	GtkWidget *plugins;
+
 	/* Sidebar */
 	GtkWidget *sidebar;
 	gboolean sidebar_shown;
 	int sidebar_w;
 
-	/* Separate Dialogs */
-	GtkWidget *properties;
-	TotemSkipto *skipto;
-
 	/* Play/Pause */
 	GtkWidget *pp_button;
 	/* fullscreen Play/Pause */
 	GtkWidget *fs_pp_button;
-	GtkTooltips *tooltip;
 
 	/* Seek */
 	GtkWidget *seek;
 	GtkAdjustment *seekadj;
 	gboolean seek_lock;
 	gboolean seekable;
-	gboolean was_playing;
-	gboolean seek_in_progress;
 
 	/* Volume */
 	GtkWidget *volume;
@@ -147,7 +142,8 @@ struct Totem {
 	gboolean popup_in_progress;
 	GdkRectangle fullscreen_rect;
 
-	TotemScrsaver *scr;
+	/* Stream info */
+	gint64 stream_length;
 
 	/* recent file stuff */
 	GtkRecentManager *recent_manager;
@@ -162,6 +158,7 @@ struct Totem {
 	const char *argv0;
 	gint64 seek_to;
 	guint index;
+	gboolean session_restored;
 
 	/* Window State */
 	int window_w, window_h;
@@ -171,7 +168,6 @@ struct Totem {
 	char *mrl;
 	TotemPlaylist *playlist;
 	GConfClient *gc;
-	TotemRemote *remote;
 	BaconMessageConnection *conn;
 	TotemStates state;
 	gboolean cursor_shown;
@@ -195,12 +191,8 @@ void	totem_action_take_screenshot		(Totem *totem);
 void	totem_action_zoom_relative		(Totem *totem, int off_pct);
 void	totem_action_zoom_reset			(Totem *totem);
 void	totem_action_show_help			(Totem *totem);
-void	totem_action_skip_to			(Totem *totem);
+void	totem_action_show_properties		(Totem *totem);
 
 void	show_controls				(Totem *totem, gboolean was_fullscreen);
 
-gboolean totem_is_fullscreen			(Totem *totem);
-
-
-
 #endif /* __TOTEM_PRIVATE_H__ */
