@@ -34,9 +34,10 @@
 #include "totem-uri.h"
 #include "totem-private.h"
 
-static GtkFileFilter *filter_all;
-static GtkFileFilter *filter_supported;
-static GtkFileFilter *filter_audio, *filter_video;
+static GtkFileFilter *filter_all = NULL;
+static GtkFileFilter *filter_supported = NULL;
+static GtkFileFilter *filter_audio = NULL;
+static GtkFileFilter *filter_video = NULL;
 
 static char *xdg_user_dir_lookup (const char *type);
 
@@ -49,6 +50,41 @@ totem_playing_dvd (const char *uri)
 	return g_str_has_prefix (uri, "dvd:/");
 }
 
+static void
+totem_ensure_dot_dir (const char *path)
+{
+	if (g_file_test (path, G_FILE_TEST_IS_DIR) != FALSE)
+		return;
+
+	g_mkdir_with_parents (path, 0700);
+}
+
+const char *
+totem_dot_dir (void)
+{
+	static char *totem_dir = NULL;
+
+	if (totem_dir != NULL) {
+		totem_ensure_dot_dir (totem_dir);
+		return totem_dir;
+	}
+
+	totem_dir = g_build_filename (g_get_home_dir (),
+				      ".gnome2",
+				      "Totem",
+				      NULL);
+
+	totem_ensure_dot_dir (totem_dir);
+
+	return (const char *)totem_dir;
+}
+
+char *
+totem_pictures_dir (void)
+{
+	return xdg_user_dir_lookup ("PICTURES");
+}
+
 gboolean
 totem_is_media (const char *uri)
 {
@@ -67,6 +103,17 @@ totem_is_media (const char *uri)
 	return FALSE;
 }
 
+gboolean
+totem_is_special_mrl (const char *uri)
+{
+	if (uri == NULL)
+		return FALSE;
+	if (g_str_has_prefix (uri, "dvb:") != FALSE)
+		return TRUE;
+
+	return totem_is_media (uri);
+}
+
 gboolean
 totem_is_block_device (const char *uri)
 {
@@ -98,12 +145,11 @@ totem_create_full_path (const char *path)
 	g_return_val_if_fail (path != NULL, NULL);
 
 	if (strstr (path, "://") != NULL)
-		return g_strdup (path);
-	if (totem_is_media (path) != FALSE)
-		return g_strdup (path);
+		return NULL;
+	if (totem_is_special_mrl (path) != FALSE)
+		return NULL;
 
-	if (path[0] == '/')
-	{
+	if (path[0] == G_DIR_SEPARATOR) {
 		escaped = gnome_vfs_escape_path_string (path);
 
 		retval = g_strdup_printf ("file://%s", escaped);
@@ -113,8 +159,8 @@ totem_create_full_path (const char *path)
 
 	curdir = g_get_current_dir ();
 	escaped = gnome_vfs_escape_path_string (curdir);
-	curdir_withslash = g_strdup_printf ("file://%s%s",
-			escaped, G_DIR_SEPARATOR_S);
+	curdir_withslash = g_strdup_printf ("file://%s%c",
+					    escaped, G_DIR_SEPARATOR);
 	g_free (escaped);
 	g_free (curdir);
 
@@ -158,8 +204,8 @@ static const char subtitle_ext[][4] = {
 char *
 totem_uri_get_subtitle_uri (const char *uri)
 {
-	char *suffix, *subtitle;
-	guint len, i;
+	char *subtitle;
+	guint len, i, suffix;
 	GnomeVFSURI *vfsuri;
 
 	if (g_str_has_prefix (uri, "http") != FALSE) {
@@ -172,19 +218,37 @@ totem_uri_get_subtitle_uri (const char *uri)
 		return NULL;
 	gnome_vfs_uri_unref (vfsuri);
 
+	/* Has the user specified a subtitle file manually? */
 	if (strstr (uri, "#subtitle:") != NULL) {
 		return NULL;
 	}
 
+        /* Find the filename suffix delimiter */
 	len = strlen (uri);
-	if (uri[len-4] != '.') {
+	for (suffix = len-1; suffix > 0; suffix--) {
+		if (uri[suffix] == G_DIR_SEPARATOR ||
+                    (uri[suffix] == '/')) {
+			/* This filename has no extension, we'll need to 
+			 * add one */
+			suffix = len;
+			break;
+		}
+		if (uri[suffix] == '.') {
+			/* Found our extension marker */
+			break;
+		}
+	}
+        if (suffix < 0) {
 		return NULL;
 	}
 
-	subtitle = g_strdup (uri);
-	suffix = subtitle + len - 4;
+	/* Generate a subtitle string with room at the end to store the
+	 * 3 character extensions we want to search for */
+	subtitle = g_strdup_printf ("%.*s.???", suffix, uri);
+	
+	/* Search for any files with one of our known subtitle extensions */
 	for (i = 0; i < G_N_ELEMENTS(subtitle_ext) ; i++) {
-		memcpy (suffix + 1, subtitle_ext[i], 3);
+		memcpy (subtitle + suffix + 1, subtitle_ext[i], 3);
 
 		vfsuri = gnome_vfs_uri_new (subtitle);
 		if (vfsuri != NULL) {
@@ -270,10 +334,22 @@ totem_setup_file_filters (void)
 void
 totem_destroy_file_filters (void)
 {
-	g_object_unref (filter_all);
-	g_object_unref (filter_supported);
-	g_object_unref (filter_audio);
-	g_object_unref (filter_video);
+	if (filter_all != NULL) {
+		g_object_unref (filter_all);
+		filter_all = NULL;
+	}
+	if (filter_supported != NULL) {
+		g_object_unref (filter_supported);
+		filter_supported = NULL;
+	}
+	if (filter_audio != NULL) {
+		g_object_unref (filter_audio);
+		filter_audio = NULL;
+	}
+	if (filter_video != NULL) {
+		g_object_unref (filter_video);
+		filter_video = NULL;
+	}
 }
 
 static const char *dir_types[] = {
@@ -296,6 +372,20 @@ totem_add_default_dirs (GtkFileChooser *dialog)
 	}
 }
 
+void
+totem_add_pictures_dir (GtkWidget *chooser)
+{
+	char *dir;
+
+	g_return_if_fail (GTK_IS_FILE_CHOOSER (chooser) != FALSE);
+
+	dir = xdg_user_dir_lookup ("PICTURES");
+	if (dir == NULL)
+		return;
+	gtk_file_chooser_add_shortcut_folder (GTK_FILE_CHOOSER (chooser), dir, NULL);
+	g_free (dir);
+}
+
 GSList *
 totem_add_files (GtkWindow *parent, const char *path)
 {
